"""Top-level package for the MiniOMM software"""

__author__ = """Toni Giorgino"""
__email__ = "toni.giorgino@gmail.com"
__version__ = "0.1.1"
